pub struct ParseOptions {
pub suppress_errors: bool,
}Expand description
Parser behavior switches shared by metadata, semantic JSON, and typed render-model parsing.
Fields
suppress_errors: boolReturn an error diagram model instead of an error when diagram parsing fails.
Implementations
Sourceimpl ParseOptions
impl ParseOptions
Sourcepub fn strict() -> ParseOptions
pub fn strict() -> ParseOptions
Strict parsing (errors are returned).
Sourcepub fn lenient() -> ParseOptions
pub fn lenient() -> ParseOptions
Lenient parsing: on parse failures, return an error diagram instead of returning an error.